@@ -1,6 +1,7 @@
 from __future__ import annotations
 import copy
 import warnings
+import re
 
 class Schema(object):
 
@@ -26,6 +27,8 @@ class Schema(object):
         Class to represent the 
         caracteristics of a field.
         """
+
+
         def __init__(self
             , name:str
             , ftype=str
@@ -101,10 +104,16 @@ class Schema(object):
             return self
 
         def set_name(self, name:str):
+            # valida a variavel
+            if type(name) is not str:
+                raise Exception("The field name must be a string.")
+            if not re.fullmatch(re.compile(r"[A-Za-z0-9]+"), name):
+                raise Exception("Fields must have alphanumeric names, containing only letters and numbers.")
+            if re.fullmatch(re.compile(r"[0-9]"), name):
+                raise Exception("Field names must always start with letters.")
             self._f['name'] = name
             return self
 
-        # TODO: caso o nome for nulo, fazer com que retorne um nome padrao
         def get_name(self, use_alias=True):
             """
             Gets the field name. If field has 
@@ -279,9 +288,7 @@ class Schema(object):
         , default=None
         , primary_key:bool=False
         , auto_increment:int=0
-        , optional:bool=False
-        # TODO remover a propriedade "null". "optional" entra no lugar.
-        , null:bool=True):
+        , optional:bool=False):
         if not name:
             name = self.gen_field_name()
         if ftype=='string':
@@ -330,21 +337,14 @@ class Schema(object):
         , auto_increment:int=0
         , optional:bool=False
         , col_ref:int=None
-        , pos:str='a'
-        # TODO remover a propriedade "null". "optional" entra no lugar.
-        , null:bool=None)->_Field:
-        if null is not None:
-            warnings.warn('The "null" property will be deprecated. Use "optional" instead.')
-            # optional = null
+        , pos:str='a')->_Field:
         f = self._gen_field(name=name
             , ftype=ftype
             , size=size
             , default=default
             , primary_key=primary_key
             , auto_increment=auto_increment
-            , optional=optional
-            # TODO remover a propriedade "null". "optional" entra no lugar.
-            , null=null)
+            , optional=optional)
         f.set_schema(self)
         self.append_field(field=f, col_ref=col_ref, pos=pos)
         if primary_key:
